==> samplechartfetch-0.0.11.tgz: package/MarketReport.tsx <==
import React, { useState, useEffect } from 'react';
import Chart from 'chart.js/auto';

interface MarketData {
  metric_values: {
    [key: string]: {
      value: number;
      unit: string;
    };
  };
}

interface MarketDataFetcherProps {
  apiKey: string;
  currency: string;
  blockchain: number;
  metrics: string[];
  time_range: string;
  include_washtrade: boolean;
}

const MarketReport: React.FC<MarketDataFetcherProps> = ({
  apiKey,
  currency,
  blockchain,
  metrics,
  time_range,
  include_washtrade,
}) => {
  const [marketData, setMarketData] = useState<MarketData | null>(null);
  const [isLoading, setIsLoading] = useState<boolean>(true);
  const [error, setError] = useState<string | null>(null);
   console.log(marketData)
  useEffect(() => {
    const fetchData = async () => {
      try {
        setIsLoading(true);
        const queryString = new URLSearchParams({
          currency,
          blockchain: blockchain.toString(),
          metrics: metrics.join(','),
          time_range,
          include_washtrade: include_washtrade.toString(),
        }).toString();

        const apiUrl = `https://api.unleashnfts.com/api/v1/market/metrics?${queryString}`;

        const response = await fetch(apiUrl, {
          headers: {
            'x-api-key': apiKey,
          },
        });

        if (!response.ok) {
          throw new Error('Failed to fetch data');
        }

        const data: MarketData = await response.json();
        setMarketData(data);
        setError(null);
      } catch (error) {
        setError('Failed to fetch data');
      } finally {
        setIsLoading(false);
      }
    };

    fetchData();
  }, [apiKey, currency, blockchain, metrics, time_range, include_washtrade]);

  useEffect(() => {
    if (!marketData) return;

    const labels: string[] = [];
    const values: number[] = [];

    for (const metric in marketData.metric_values) {
      labels.push(metric);
      values.push(marketData.metric_values[metric].value);
    // values.push(100);
    }

    const ctx = document.getElementById('marketDataChart') as HTMLCanvasElement;
    const chart = new Chart(ctx, {
      type: 'line',
      data: {
        labels: labels,
        datasets: [
          {
            label: 'Market Data',
            data: values,
            fill: false,
            borderColor: 'rgba(75, 192, 192, 1)',
            tension: 0.1,
          },
        ],
      },
      options: {
        responsive: true,
        plugins: {
          title: {
            display: true,
            text: 'Market',
          },
        },
        scales: {
          y: {
            beginAtZero: true,
          },
        },
      },
    });

    return () => {
      chart.destroy();
    };
  }, [marketData]);

  if (isLoading) {
    return <div>Loading...</div>;
  }

  if (error) {
    return <div>Error: {error}</div>;
  }

  return <canvas id="marketDataChart" />;
};

export default MarketReport;

==> samplechartfetch-0.0.12.tgz: package/MarketReport.tsx <==
import React, { useState, useEffect } from 'react';
import Chart from 'chart.js/auto';

interface MarketData {
  metric_values: {
    [key: string]: {
      value: number;
      unit: string;
    };
  };
}

interface MarketReportProps {
  apiKey: string;
  currency?: string;
  metrics: string[];
  time_range?: string;
  include_washtrade?: boolean;
}

const MarketReport: React.FC<MarketReportProps> = ({
  apiKey,
  currency,
  metrics,
  time_range,
  include_washtrade,
}) => {
  const [marketData, setMarketData] = useState<MarketData | null>(null);
  const [isLoading, setIsLoading] = useState<boolean>(true);
  const [error, setError] = useState<string | null>(null);

  useEffect(() => {
    const fetchData = async () => {
      try {
        setIsLoading(true);

        let apiUrl = `https://api.unleashnfts.com/api/v1/market/metrics?`;

        // Append currency to apiUrl if it's provided
        if (currency) {
          apiUrl += `currency=${encodeURIComponent(currency)}&`;
        }

        // Append metrics to apiUrl
        apiUrl += metrics.map(metric => `metrics=${encodeURIComponent(metric)}`).join('&');

        // Append time_range to apiUrl if it's provided
        if (time_range) {
          apiUrl += `&time_range=${encodeURIComponent(time_range)}`;
        }

        // Append include_washtrade to apiUrl if it's provided
        if (include_washtrade !== undefined) {
          apiUrl += `&include_washtrade=${include_washtrade}`;
        }

        const response = await fetch(apiUrl, {
          headers: {
            'x-api-key': apiKey,
          },
        });

        if (!response.ok) {
          throw new Error('Failed to fetch data');
        }

        const data: MarketData = await response.json();
        setMarketData(data);
        setError(null);
      } catch (error) {
        setError('Failed to fetch data');
      } finally {
        setIsLoading(false);
      }
    };

    fetchData();
  }, [apiKey, currency, metrics, time_range, include_washtrade]);

  useEffect(() => {
    if (!marketData) return;

    const labels: string[] = [];
    const values: number[] = [];

    for (const metric in marketData.metric_values) {
      labels.push(metric);
      values.push(marketData.metric_values[metric].value);
    }

    const ctx = document.getElementById('marketDataChart') as HTMLCanvasElement;
    const chart = new Chart(ctx, {
      type: 'line',
      data: {
        labels: labels,
        datasets: [
          {
            label: 'Market Data',
            data: values,
            fill: false,
            borderColor: 'rgba(75, 192, 192, 1)',
            tension: 0.1,
          },
        ],
      },
      options: {
        responsive: true,
        plugins: {
          title: {
            display: true,
            text: 'Market',
          },
        },
        scales: {
          y: {
            
            beginAtZero: true,
          },
        },
      },
    });

    return () => {
      chart.destroy();
    };
  }, [marketData]);

  if (isLoading) {
    return <div>Loading...</div>;
  }

  if (error) {
    return <div>Error: {error}</div>;
  }

  return <canvas id="marketDataChart" />;
};

export default MarketReport;
